// Copyright 1994 by Jon Dart.  All Rights Reserved.

#include <wpmain.h>
#include "board.h"
#include "search.h"
#include "srclimit.h"
#include "log.h"
#include "book.h"
#include "clock.h"
#include "rmove.h"
#include <wpglob.h>
#include <time.h>

class Display;

APPCLASS Chess : public WPMainWin 
{
	// main application window.

public:
	Chess();
	virtual ~Chess();
	void paint(WPPaintStruct &ps);
	BOOL mouse( int msg, WPPoint p, WORD flags );
	BOOL menuInit(WPMenu &menu);
	BOOL command( int id, WORD msg );
	BOOL timer(int id);
	BOOL sized(WPRect &box, WORD how);
	ColorType side_to_move() const
	{
	    return current_board.Side();
	}
private:
	void reset();
	void compute_move(Board &board, const Search::Search_Type search_type,
	    const Search::Search_Limit limit, const Boolean background,
	    Search::Statistics &stats,
	    ExtendedMove &emove);
	void update_board(const ExtendedMove &emove, 
		const Search::Statistics *stats,
		const Boolean update_log);

	void draw_board();

	void show_side();

	void show_last_move();

	void show_last_move( char *move_image );
	
	void computer_plays( const ColorType side );

	Board current_board;
	Book book;
	Log log;
	Display *display;
	Search *searcher;
        Search_Limit_Options options;
	Search::Statistics stats;
	time_t etime[2]; // elapsed time for each side
        time_t last_start[2];		
	Square start_square; // for move
	ReversibleMove last_move;
	ExtendedMove predicted_move;
	char last_move_image[12];
	Boolean searching;
	Boolean users_move;
	Boolean use_book;
	Boolean no_prev_search;
	Boolean quitting;
	int last_cmd;
	ColorType computer_side;
};

