// Copyright 1993 by Jon Dart.  All Rights Reserved.

#include "clock.h"
#include "display.h"

Clock::Clock( HWND parent )
: pWin(parent), running(True), side_to_move(White)
{
    reset();
}

Clock::~Clock()
{
}

void Clock::reset()
{
     etime[White] = etime[Black] = 0;
     last_start[White] = time(NULL);
     Display::show_time(pWin,(time_t)0,White);
     Display::show_time(pWin,(time_t)0,Black);
     was_reset = True;
     running = True;
     stopped = False;
}

void Clock::start( const ColorType side )
{
     const ColorType oside = OppositeColor(side);
     if (!was_reset)
     {
        etime[oside] += time(NULL) - last_start[oside];
        Display::show_time(pWin,elapsed_time(oside),oside);
     }
     was_reset = False;
     last_start[side] = time(NULL);
     side_to_move = side;
     running = True;
     stopped = False;
}

void Clock::pause()
{
     running = False;
}

void Clock::resume()
{
     running = True;
}

void Clock::stop()
{
     running = False;
     stopped = True;
}

void Clock::update()
{
   if (running)
       Display::show_time(pWin,
       		elapsed_time(side_to_move) + time(NULL) - 
		last_start[side_to_move], side_to_move);
}