// Copyright 1994 by Jon Dart.  All Rights Reserved.

#include "options.h"
#include <stdlib.h> // for atoi

static char ini_file[] = "arasan.ini";

Options::Options()
{
#ifdef WINDOWS
   char opt_str[80];
   GetPrivateProfileString("Search Limits","Search Type","Fixed",
   	(LPSTR)opt_str,80,ini_file);
   if (strcmp(opt_str,"Time")==0)
   {
      my_search_type = Search::Time_Limit;
      GetPrivateProfileString("Search Limits","Moves","60",
   	(LPSTR)opt_str,80,ini_file);
      my_search_limit.limit.moves = atoi(opt_str);            
      GetPrivateProfileString("Search Limits","Minutes","60",
   	(LPSTR)opt_str,80,ini_file);
      my_search_limit.limit.minutes = atoi(opt_str);
   }
   else
   {
      my_search_type = Search::Fixed_Ply;
      GetPrivateProfileString("Search Limits","ply","2",
   	(LPSTR)opt_str,80,ini_file);
      my_search_limit.max_ply = atoi(opt_str);            
   }
   GetPrivateProfileString("Preferences","Beep After Move","True",
  	(LPSTR)opt_str,80,ini_file);
   prefs.beep_after_move = (strcmp(opt_str,"True")==0) ;
   GetPrivateProfileString("Preferences","Beep On Error","True",
  	(LPSTR)opt_str,80,ini_file);
   prefs.beep_on_error = (strcmp(opt_str,"True")==0) ;
   GetPrivateProfileString("Preferences","Can Resign","True",
  	(LPSTR)opt_str,80,ini_file);
   prefs.can_resign = (strcmp(opt_str,"True")==0) ;
   GetPrivateProfileString("Preferences","Use Book","True",
  	(LPSTR)opt_str,80,ini_file);
   prefs.use_book = (strcmp(opt_str,"True")==0) ;
   GetPrivateProfileString("Preferences","Think When Idle","True",
  	(LPSTR)opt_str,80,ini_file);
   prefs.think_when_idle = (strcmp(opt_str,"True")==0) ;
#else
   // set some default options
   my_search_type = Search::Fixed_Ply;
   my_search_limit.max_ply = 2;
   prefs.beep_after_move = True;
   prefs.beep_on_error = True;
   prefs.can_resign = True;
   prefs.randomize_moves = False;
   prefs.use_book = True;
   prefs.think_when_idle = False;
#endif
}

Options::~Options()
{
   save();
}

void Options::get_preferences( Preferences &p )
{
    p = prefs;
}

void Options::update_preferences( const Preferences &p)
{
    prefs = p;
}

void Options::save()
{
#ifdef WINDOWS
   char msg[40];
   if (my_search_type == Search::Fixed_Ply)
   {
      WritePrivateProfileString("Search Limits","Search Type","Fixed",
         ini_file);
      wsprintf(msg,"%d",my_search_limit.max_ply);
      WritePrivateProfileString("Search Limits","ply",msg,ini_file);
   }
   else
   {
      WritePrivateProfileString("Search Limits","Search Type","Time",
         ini_file);
      wsprintf(msg,"%d", my_search_limit.limit.moves);
      WritePrivateProfileString("Search Limits","Moves",msg,ini_file);
      wsprintf(msg,"%d", my_search_limit.limit.minutes);
      WritePrivateProfileString("Search Limits","Minutes",msg,ini_file);
   }
   static char *boolImage[2] = { "False", "True" };
   WritePrivateProfileString("Preferences","Beep After Move",
      boolImage[(int)beep_after_move()],ini_file);
   WritePrivateProfileString("Preferences","Beep On Error",
      boolImage[(int)beep_on_error()],ini_file);
   WritePrivateProfileString("Preferences","Can Resign",
      boolImage[(int)can_resign()],ini_file);
   WritePrivateProfileString("Preferences","Use Book",
      boolImage[(int)use_book()],ini_file);
   WritePrivateProfileString("Preferences","Think When Idle",
      boolImage[(int)think_when_idle()],ini_file);
#endif
}
