// Copyright 1994 by Jon Dart.  All Rights Reserved.

#ifndef _PINFO_H
#define _PINFO_H

#include "move.h"
#include <stddef.h>

class Position_Info;

class Position_Info
{
    // this class represents one entry in the hash table.

    public:

    friend unsigned long hash_code(Position_Info &p);
    
    enum ValueType { Invalid, Valid, UpperBound, LowerBound };

    Position_Info( const int ply, const int depth,
	           const ValueType hashflags,
		   const Boolean forced,
		   const unsigned long hashcode, 
		   const int value,
		   const Move &best_move)
    : my_ply((byte)ply), my_depth((byte)depth),
      my_hashcode(hashcode),my_value(value),my_best_move(best_move)
    {
	    my_flags = (byte)hashflags;
	    if (forced)
		    my_flags |= 8;
     }

    Position_Info( const unsigned long hashcode )
    : my_ply(0),my_depth(0),
      my_hashcode(hashcode),my_flags(Invalid),my_value(0),
      my_best_move(Move::NullMove())
    {
    }
    
    int operator == ( const Position_Info &p)
    {
        return (my_hashcode == p.my_hashcode);
    }

    ValueType type() const
    {
        return (ValueType)(my_flags & 0x7);
    }
    
    Boolean forced() const
    {
	 return (my_flags & 8) != 0;
    }

    unsigned long hash_code() const
    {
        return my_hashcode;
    }
    
    int depth() const
    {
	return my_depth;
    }
    
    int value() const
    {
	return my_value;
    }
    
    const Move &best_move() const
    {
	return my_best_move;
    }

    private:

    byte my_ply, my_depth;
    byte my_flags;
    unsigned long my_hashcode;
    int my_value;
    Move my_best_move;
};

unsigned long hash_code(const Position_Info &p);

#endif
