// Copyright 1994 by Jon Dart.  All Rights Reserved.

// Stand-alone DOS executable to test the search engine

#include "board.h"
#include "movegen.h"
#include "search.h"
#include "options.h"
#include "movearr.h"
#include "notation.h"
extern "C"
{
#include <string.h>
#include <ctype.h>
#include <assert.h>
};
#include <fstream.h>
#include <iostream.h>
#include <time.h>

Options *global_options;
Move_Array *game_moves;

int main(int argc, char **argv)
{
   Board board;
   Search searcher;
   Search::Statistics stats;
   Search::Search_Limit limit;
   Search::Search_Type type = Search::Fixed_Ply;
   limit.max_ply = 2;
   int arg = 1;

   if (argc ==1)
   {
         cerr << "Usage: testsrc [-t seconds] [-p plies] position" << endl;
	 return -1;
   }
   else
   {
   	if (*(argv[arg]) == '-')
	{
	   char c = tolower(*(argv[arg]+1));
	   switch (c)
	   {
	      case 'p':
	         type = Search::Fixed_Ply; break;
	      case 't':
	         type = Search::Time_Limit; break;
	      default:
                cerr << "Usage: testsrc [-t seconds] [-p plies] position" << endl;
		return -1;
	   }
	   ++arg;
	   if (argc <= 2)
	   {
                cerr << "Usage: testsrc [-t seconds] [-p plies] position" << endl;
		return -1;
	   }
	   if (type == Search::Fixed_Ply)
	      limit.max_ply = atoi(argv[arg]);
	   else
	   {
	      limit.limit.moves = 100;
	      limit.limit.minutes = (100*atoi(argv[arg]))/60;
	   }
	   ++arg;
	}

	ifstream pos_file( argv[arg],
#ifdef __BORLANDC__
	     ios::in | ios::noreplace | ios::binary );
#else
	     ios::in | ios::noreplace );
#endif
	if (pos_file.good())
	{
	   pos_file >> board ;
	   if (!pos_file)
	   {
	      cout << "Bad format!" << endl;
	      return -1;
	   }
	   pos_file.close();
	}
	else
	{
	  cout << "file not found: " << argv[arg] << endl;
	  return -1;
	}
    }

    global_options = new Options();
    game_moves = new Move_Array();

    Move move = searcher.find_best_move(board, type, limit,
      stats, Move::NullMove(), False );

    ExtendedMove emove(board,move);
    char move_text[20];
    Notation::Image(board, emove, move_text);
    board.MakeMove(emove);
    cout << argv[arg];
    if (strlen(argv[arg]) % 8 != 0)
	cout << '\t';
    cout << '\t' << move_text << "\t" << stats.elapsed_time <<
     " seconds.\t" << stats.num_moves << " moves.\t" <<
     stats.num_pos << " positions." 
	/* << "\tpredicted: " << stats.best_line[1].Image() */
	<< endl;

    delete game_moves;
    delete global_options;
    return 0;
}
